==> ult-statemachine-domain-0.0.16-sources.jar: com/xforceplus/ultstatemachine/entity/ComboStateMachineScope.java <==
package com.xforceplus.ultstatemachine.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonFormat;
import java.util.List;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2020-11-27
 */
@Data
public class ComboStateMachineScope extends StateMachineScope {
  public ComboStateMachineScope() {}

  public ComboStateMachineScope(StateMachineScope stateMachineScope) {
      this.setScopeCode(stateMachineScope.getScopeCode());
      this.setScopeName(stateMachineScope.getScopeName());
      this.setScopeField(stateMachineScope.getScopeField());
      this.setTenantName(stateMachineScope.getTenantName());
      this.setId(stateMachineScope.getId());
      this.setTenantId(stateMachineScope.getTenantId());
      this.setTenantCode(stateMachineScope.getTenantCode());
      this.setCreateTime(stateMachineScope.getCreateTime());
      this.setUpdateTime(stateMachineScope.getUpdateTime());
      this.setCreateUserId(stateMachineScope.getCreateUserId());
      this.setUpdateUserId(stateMachineScope.getUpdateUserId());
      this.setCreateUserName(stateMachineScope.getCreateUserName());
      this.setUpdateUserName(stateMachineScope.getUpdateUserName());
      this.setDeleteFlag(stateMachineScope.getDeleteFlag());
  }

  private List<ComboStateMachineScopeValue> comboStateMachineScopeValues;

}

==> ult-statemachine-domain-0.0.43-sources.jar: com/xforceplus/ultstatemachine/entity/ComboStateMachineScope.java <==
package com.xforceplus.ultstatemachine.entity;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonFormat;
import java.util.List;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2020-12-02
 */
@Data
public class ComboStateMachineScope extends StateMachineScope {
  public ComboStateMachineScope() {}

  public ComboStateMachineScope(StateMachineScope stateMachineScope) {
      this.setScopeCode(stateMachineScope.getScopeCode());
      this.setScopeName(stateMachineScope.getScopeName());
      this.setScopeField(stateMachineScope.getScopeField());
      this.setTenantName(stateMachineScope.getTenantName());
      this.setId(stateMachineScope.getId());
      this.setTenantId(stateMachineScope.getTenantId());
      this.setTenantCode(stateMachineScope.getTenantCode());
      this.setCreateTime(stateMachineScope.getCreateTime());
      this.setUpdateTime(stateMachineScope.getUpdateTime());
      this.setCreateUserId(stateMachineScope.getCreateUserId());
      this.setUpdateUserId(stateMachineScope.getUpdateUserId());
      this.setCreateUserName(stateMachineScope.getCreateUserName());
      this.setUpdateUserName(stateMachineScope.getUpdateUserName());
      this.setDeleteFlag(stateMachineScope.getDeleteFlag());
  }

  private List<StateMachineScopeValue> stateMachineScopeValues;

}
